@@ -1,6 +1,6 @@
 /*
  * KAKASI (Kanji Kana Simple inversion program)
- * $Id: dict.c,v 1.8 2001/09/03 10:02:38 rug Exp $
+ * $Id: dict.c,v 1.13 2014-02-13 07:30:35 knok Exp $
  * Copyright (C) 1992
  * Hironobu Takahashi (takahasi@tiny.or.jp)
  *
@@ -42,6 +42,11 @@
 # include <malloc.h>
 #endif
 #include <stdlib.h>
+#ifdef HAVE_STDINT_H
+# include <stdint.h>
+#else
+typedef int uintptr_t;
+#endif
 #include "kakasi.h"
 
 #define BUFLEN 1024
@@ -119,7 +124,7 @@ cellalloc()
 	char *cptr;
 	cptr = malloc((CELLALLOC+1)*sizeof(struct kanji_yomi));
 	add_ary_cellalloc(cptr);
-	if ((int)cptr & 7) cptr += 8 - ((int)cptr & 7);
+	if ((uintptr_t)cptr & 7) cptr += 8 - ((uintptr_t)cptr & 7);
 	ptr_cellalloc = (struct kanji_yomi *) cptr;
 	point_cellalloc = 0;
     }
@@ -193,7 +198,11 @@ static void add_item(yomi, kanji, tail)
     /* Isn't the one except for the KANA contained? A KATAKANA changes into the HIRAGANA. */
     for (q = yomi; (q[0] != '\0') && (q[1] != '\0'); q += 2) {
 	if (*q < 0xa1) return;
-	if (*q == 0xa5) *q = 0xa4;
+	if (*q == 0xa5) {
+	    *q = 0xa4;
+	    if (q[1] >= 0xf4 && q[1] <= 0xf6) /* skip when input is "vu", small "ka", small "ke"  */
+		return;
+	}
 	if ((*q != 0xa4) &&
 	    ((q[0] != 0xa1) || (q[1] != 0xbc)) && /* Prolonged sound */ 
 	    ((q[0] != 0xa1) || (q[1] != 0xab)) && /* Sonant */
@@ -295,15 +304,34 @@ void add_jisyo(filename)
 
 #ifdef LIBRARY
 FILE *kanwadict = NULL;
+unsigned short dict_endian_mark;
 #else
 static FILE *kanwadict;
+static unsigned short dict_endian_mark;
 #endif
 
+static void
+fix_dict_endian_int(int *v)
+{
+    unsigned char *p;
+    int i;
+    if (dict_endian_mark == 0xFEFF) {
+	/* native endian */
+	return;
+    }
+    i = 0;
+    p = (unsigned char *)v;
+    i = (p[3]<<24) | (p[2]<<16) | (p[1]<<8) | p[0];
+    *v = i;
+}
+
 void init_kanwa()
 {
     int i, j;
     
     char *kanwadictpath;
+    char magic[6];
+    int kanwa_offset;
 
     kanwadictpath = (char*)getenv("KANWADICTPATH");
     if (kanwadictpath == (char*)NULL)
@@ -316,10 +344,30 @@ void init_kanwa()
 	exit(2);
     }
 
+    fread(magic, 6, 1, kanwadict);
+    if (memcmp(magic, "KAKASI", 6) == 0) {
+	fread(&dict_endian_mark, 2, 1, kanwadict);
+	fread(&kanwa_offset, sizeof(int), 1, kanwadict);
+	fix_dict_endian_int(&kanwa_offset);
+	/* XXX: ignore options */
+	fseek(kanwadict, kanwa_offset, SEEK_SET);
+    } else {
+	dict_endian_mark = 0;
+    }
+
     if (fread((char *)kanwa, sizeof kanwa, 1, kanwadict) != 1) {
 	perror(kanwadictpath);
     }
 
+    if (dict_endian_mark) {
+	for (i = 0x20; i < 0x7f; i++) {
+	    for (j = 0x20; j < 0x7f; j++) {
+		fix_dict_endian_int(&kanwa[i-0x20][j-0x20].index);
+		fix_dict_endian_int(&kanwa[i-0x20][j-0x20].entry);
+	    }
+	}
+    }
+
     for (i = 0; i < 0x80; ++ i)
 	for (j = 0; j < 0x80; ++ j)
 	    kanwa_load[i][j] = 0;
