@@ -1,6 +1,6 @@
 /*
  * KAKASI (Kanji Kana Simple inversion program)
- * $Id: ee2.c,v 1.1.1.1 2000/03/04 05:37:56 rug Exp $
+ * $Id: ee2.c,v 1.4 2003-03-12 13:00:12 knok Exp $
  * Copyright (C) 1992
  * Hironobu Takahashi (takahasi@tiny.or.jp)
  *
@@ -20,9 +20,14 @@
  * 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include "kakasi.h"
 
-static void E2alphabet_copy(n, str, type)
+static void
+E2alphabet_copy(n, str, type)
      Character *n;
      char *str;
      int type;
@@ -38,7 +43,8 @@ static void E2alphabet_copy(n, str, type)
     n[i].c2 = 0;
 }
 
-static int E2alphabet(c, n, type)
+static int
+E2alphabet(c, n, type)
      Character *c;
      Character *n;
      int type;
@@ -50,7 +56,7 @@ static int E2alphabet(c, n, type)
 	"|","...","..","`","'","\"","\"","(",")","[","]","[","]","{","}","<",">",
 	"<<",">>","(",")","(",")","(",")","+","-","+-","X","/","=","!=","<",">",
 	"<=",">=","(kigou)","...","(osu)","(mesu)","(do)","'","\"","(Sessi)","\\",
-	"$","(cent)","(fran)","%","#","&","*","@","(setu)","(hosi)","(hosi)","(maru)",
+	"$","(cent)","(pound)","%","#","&","*","@","(setu)","(hosi)","(hosi)","(maru)",
 	"(maru)","(maru)","(diamond)" };
     static char E2greek_table[56][8] = {
 	"Alpha", "Beta", "Gamma", "Delta", "Epsilon", "Zeta", "Eta", "Theta",
@@ -106,14 +112,16 @@ static int E2alphabet(c, n, type)
     }
 }
 
-int E2a(c, n)
+int
+E2a(c, n)
      Character *c;
      Character *n;
 {
     return E2alphabet(c, n, ASCII);
 }
 
-int E2j(c, n)
+int
+E2j(c, n)
      Character *c;
      Character *n;
 {
